@@ -49,13 +49,13 @@ def build_html(gallery_config):
     with open(gallery_config["images_data_file"], "r") as images_data_in:
         images_data = json.load(images_data_in, object_pairs_hook=OrderedDict)
 
-    images_data_list = [images_data[image] for image in images_data.keys()]
-
     # Remove descriptions if the corresponding option is enabled
     if 'disbale_captions' in gallery_config and gallery_config['disbale_captions']:
         for image in images_data:
             images_data[image]['description'] = ''
 
+    images_data_list = [{**images_data[image], "name": image} for image in images_data.keys()]
+
     # Find the first photo for the background if no background photo specified
     background_photo = gallery_config["background_photo"]
     if not background_photo:
